# Samples

Here are samples to test cx_Freeze or to show how to use a package in cx_Freeze.

# Source

https://matplotlib.org/stable/gallery/user_interfaces/embedding_in_wx2_sgskip.html

# Installation and requirements:

In a virtual environment, install by issuing the command:

```
pip install --upgrade cx_Freeze matplotlib
pip install --upgrade wxPython
```

There are wheels for ubuntu in:
https://extras.wxpython.org/wxPython4/extras/linux/gtk3/ubuntu-16.04
https://extras.wxpython.org/wxPython4/extras/linux/gtk3/ubuntu-18.04
https://extras.wxpython.org/wxPython4/extras/linux/gtk3/ubuntu-20.04

For example:

```
pip install -f https://extras.wxpython.org/wxPython4/extras/linux/gtk3/ubuntu-18.04 wxPython
```
